---
title: PivotDataSource
page_title: PivotDataSource Overview - Components - Kendo UI for Vue
description: "Use the Kendo UI PivotDataSource wrapper component in Vue projects."
slug: overview_pivotdatasource
position: 5
---

# PivotDataSource Overview

The PivotDataSource extends the [DataSource component]({% slug overview_datasource %}).

It communicates with an [OLAP cube](https://en.wikipedia.org/wiki/OLAP_cube) instance on HTTP by using the [XMLA](https://en.wikipedia.org/wiki/XML_for_Analysis) protocol.

The following example demonstrates how to bind the PivotGrid to the PivotDataSource.

{% meta height:660 %}
```html-preview
<div id="vueapp" class="vue-app">
	<kendo-pivotdatasource ref="pivotdatasource1"
						   transport-read-url="https://demos.telerik.com/kendo-ui/service/Northwind.svc/Customers"
						   type="odata"
						   :schema-cube="schemaCube"
						   :measures="measures">
		<kendo-pivot-column :name="'Country'" :expand="true"></kendo-pivot-column>
		<kendo-pivot-column :name="'CompanyName'" ></kendo-pivot-column>
		<kendo-pivot-row :name="'ContactTitle'" ></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotconfigurator id="pivotconfigurator1"
							 data-source-ref="pivotdatasource1"
							 :filterable="true"
							 :height="200" >
	</kendo-pivotconfigurator>
	<kendo-pivotgrid id="pivotgrid1"
		             data-source-ref="pivotdatasource1"
                     :filterable="true"
                     :columnWidth="120"
                     :height="400" >
	</kendo-pivotgrid>
</div>
```
```js
Vue.use(DataSourceInstaller);
Vue.use(PivotGridInstaller);

new Vue({
    el: '#vueapp',
	data: {
        measures: ['Contacts Count'],
        schemaCube: {
			dimensions: {
				ContactName: { caption: 'All Contacts' },
				CompanyName: { caption: 'All Companies' },
				Country: { caption: 'All Countries' },
				ContactTitle: { caption: 'All Titles' }
			},
			measures: {
				'Contacts Count': { field: 'CustomerID', aggregate: 'count' }
			}
        }
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI Data Source for jQuery](https://docs.telerik.com/kendo-ui/framework/datasource/overview)
* [API Reference of the Data Source Component](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource)
* [API Reference of the PivotDataSource Component](https://docs.telerik.com/kendo-ui/api/javascript/data/pivotdatasource)
